package com.famoco.smartcardexample;

import android.app.Activity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;

import com.famoco.secommunication.SmartcardReader;
import com.famoco.setest.R;

public class SmartcardReaderExampleActivity extends Activity {
	private static final String TAG = "SmartcardReaderExampleActivity";
	
	private SmartcardReader mSmartcardReader;
	
	private final static byte[] APDU_SELECT_CARD_MANAGER = new byte[]{(byte)0x00, (byte)0xA4, (byte)0x04, (byte)0x00, (byte)0x00};
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		// obtain smartcard reader instance 
		mSmartcardReader = SmartcardReader.getInstance();
		
		// open smartcard reader.
		mSmartcardReader.openReader();
		
		// power on smartcard reader
		byte[] atr = mSmartcardReader.powerOn();
		Log.d(TAG, "ATR = " + bytesToHexString(atr));
		
        Button button = (Button) findViewById(R.id.send_apdu);
        
		button.setOnClickListener(new View.OnClickListener() {
			@Override
			public void onClick(View paramView) {
				sendApdu(APDU_SELECT_CARD_MANAGER);
			}
		});	
	}
	
	private boolean sendApdu(byte[] apdu) {
		// send APDU
		Log.d(TAG, "APDU => " + bytesToHexString(APDU_SELECT_CARD_MANAGER));
		byte[] resp = mSmartcardReader.sendApdu(APDU_SELECT_CARD_MANAGER);
		Log.d(TAG, "APDU <= " + bytesToHexString(resp));
		
		return true;
	}

	
	private String bytesToHexString(byte[] bArray) {
		StringBuffer sb = new StringBuffer(bArray.length);
		String sTemp;
		for (int i = 0; i < bArray.length; i++) {
			sTemp = Integer.toHexString(0xFF & bArray[i]);
			if (sTemp.length() < 2)
				sb.append(0);
			sb.append(sTemp.toUpperCase());
		}
		return sb.toString();
	}
	
	@Override
	protected void onDestroy() {
		// power off smartcard reader
		mSmartcardReader.powerOff();
		
		// close smartcard reader
		mSmartcardReader.closeReader();
		
		super.onDestroy();
	}
	
}
